__all__ = ["PINNSolver"]

from .PDESolver import PINNSolver
